@@ -1,4 +1,3 @@
-#![feature(async_closure)]
 use anyhow::{bail, ensure, Result};
 use aqueue::Actor;
 use log::*;
@@ -98,7 +97,7 @@ where
         Ok(())
     }
     #[inline]
-    pub async fn send<'a>(&'a mut self, buff:  &'a [u8]) -> Result<usize> {
+    pub async fn send(&mut self, buff:  &[u8]) -> Result<usize> {
         if !self.disconnect {
             Ok(self.sender.write(buff).await?)
         } else {
@@ -107,7 +106,7 @@ where
     }
 
     #[inline]
-    async fn send_all<'a>(&'a mut self, buff: &'a [u8]) -> Result<()>{
+    async fn send_all(&mut self, buff: &[u8]) -> Result<()>{
         if !self.disconnect {
             Ok(self.sender.write_all(buff).await?)
         } else {
@@ -129,9 +128,9 @@ where
 pub trait SocketClientTrait {
     async fn send<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<usize>;
     async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<()>;
-    async fn send_ref<'a>(&'a self, buff: &'a [u8]) -> Result<usize>;
-    async fn send_all_ref<'a>(&'a self, buff: &'a [u8]) -> Result<()>;
-    async fn flush(&mut self) -> Result<()>;
+    async fn send_ref(&self, buff: &[u8]) -> Result<usize>;
+    async fn send_all_ref(&self, buff: &[u8]) -> Result<()>;
+    async fn flush(&self) -> Result<()>;
     async fn disconnect(&self) -> Result<()>;
 }
 
@@ -142,40 +141,37 @@ where
 {
     #[inline]
     async fn send<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<usize> {
-        self.inner_call(async move |inner| inner.get_mut().send(&buff).await)
+        self.inner_call(|inner|  async move{inner.get_mut().send(&buff).await})
             .await
     }
     #[inline]
     async fn send_all<B: Deref<Target = [u8]> + Send + Sync + 'static>(&self, buff: B) -> Result<()> {
-        self.inner_call(async move |inner| inner.get_mut().send_all(&buff).await)
+        self.inner_call(|inner| async move{ inner.get_mut().send_all(&buff).await})
             .await
     }
     #[inline]
-    async fn send_ref<'a>(&'a self, buff: &'a [u8]) -> Result<usize> {
-        ensure!(!buff.is_empty(), "send buff is null");
-        unsafe {
-            self.inner_call_ref(async move |inner| inner.get_mut().send(buff).await)
-                .await
-        }
-    }
-    #[inline]
-    async fn send_all_ref<'a>(&'a self, buff: &'a [u8]) -> Result<()> {
-        ensure!(!buff.is_empty(), "send buff is null");
-        unsafe {
-            self.inner_call_ref(async move |inner| inner.get_mut().send_all(buff).await)
-                .await
-        }
+    async fn send_ref(&self, buff: &[u8]) -> Result<usize> {
+        ensure!(!buff.is_empty(), "send buff is none");
+        self.inner_call(|inner| async move { inner.get_mut().send(buff).await })
+            .await
     }
 
     #[inline]
-    async fn flush(&mut self) -> Result<()> {
-        self.inner_call(async move |inner| inner.get_mut().flush().await)
+    async fn send_all_ref(&self, buff: &[u8]) -> Result<()> {
+        ensure!(!buff.is_empty(), "send buff is none");
+        self.inner_call(|inner| async move { inner.get_mut().send_all(buff).await })
+            .await
+    }
+
+    #[inline]
+    async fn flush(&self) -> Result<()> {
+        self.inner_call(|inner|async move { inner.get_mut().flush().await})
             .await
     }
 
     #[inline]
     async fn disconnect(&self) -> Result<()> {
-        self.inner_call(async move |inner| inner.get_mut().disconnect().await)
+        self.inner_call(|inner|  async move {inner.get_mut().disconnect().await})
             .await
     }
 }
